@@ -128,7 +128,7 @@ opts_knit$set(global.par = TRUE)
 knitr::render_sweave()  # use Sweave environments
 knitr::set_header(highlight = "")  # do not \usepackage{Sweave}
 options(prompt = "R> ", continue = "+  ", useFancyQuotes = FALSE)  # JSS style
-options(width = 74)
+options(width = 75, digits = 4)
 
 ## format
 frmtI <- function(x, math = FALSE) {
@@ -286,14 +286,14 @@ HR <- function(model,  frmt = function(x) {frmt3(x, math = FALSE)})
 
 
 
-## ----pars, include = FALSE----------------------------------------------
+## ----pars, include = FALSE-----------------------------------------------
 par_main <- expression(par(mgp = c(2.5, 1, 0), mar = c(4, 4, 1.5, 4), las = 1))
 par_surv <- expression(par(mgp = c(2.5, 1, 0), mar = c(6, 6, .5, 4), las = 1))
 
-## ----packages, echo = FALSE---------------------------------------------
+## ----packages, echo = FALSE----------------------------------------------
 library("tram")
 
-## ----risk-tab-----------------------------------------------------------
+## ----risk-tab------------------------------------------------------------
 risktab <- function(ti, st) { ## time-index and survival time
   nrisk <- NULL
   for (t in ti) nrisk <- c(nrisk, sum(st >= t))
@@ -310,76 +310,56 @@ mtext(risktab(ti, CAOsurv[CAOsurv$randarm == levs[2], tvar]),
   side = 1, line = 5, at = ti, cex = cex)
 }
 
-## ----surv-OS------------------------------------------------------------
+## ----surv-OS-------------------------------------------------------------
 surv_OS <- survfit(OS ~ randarm, data = CAOsurv) ## KM
 
-## ----surv-iDFS----------------------------------------------------------
+## ----surv-iDFS-----------------------------------------------------------
 surv_iDFS <- survfit(iDFS ~ randarm, data = CAOsurv) ## Turnbull
 
-## ----CAO-table, results = 'hide'----------------------------------------
+## ----CAO-table, results = 'hide'-----------------------------------------
 tab <- xtabs( ~ strat + randarm, data = CAOsurv)
 tab <- rbind(tab, "Total" = colSums(tab))
 
-## ----surv-iDFS-plot-----------------------------------------------------
+## ----surv-iDFS-plot------------------------------------------------------
 eval(par_surv)
 plot(surv_iDFS, ylim = ylimS, xlim = xlim,
   col = lcol, lwd = lwd, xlab = xlab, ylab = ylabS)
 legend("bottomright", legend = levs, col = col, bty = "n", lty = 1, lwd = 1, cex = .8)
 plot.risktab(tvar = "iDFStime")
 
-## ----surv-OS-plot-------------------------------------------------------
+## ----surv-OS-plot--------------------------------------------------------
 plot(surv_OS, ylim = ylimS, xlim = xlim,
   col = lcol, lwd = lwd, xlab = xlab, ylab = ylabS)
 legend("bottomright", legend = levs, col = col, bty = "n", lty = 1, lwd = 1, cex = .8)
 plot.risktab(tvar = "OStime")
 
-## ----WEI-model-fit, echo = FALSE, cache = TRUE--------------------------
+## ----WEI-model-fit, echo = FALSE, cache = TRUE---------------------------
 mw <- 
 Survreg(iDFS ~ randarm, data = CAOsurv, dist = "weibull")
 
-## ----WEI-summary, cache = TRUE, results = "hide", fig.show = 'hide'-----
+## ----WEI-summary, cache = TRUE, results = "hide", fig.show = 'hide'------
 summary(mw)
 coef(mw, as.survreg = TRUE) ## same interpretation as "survreg"
 score_test(mw)
 perm_test(mw)
 # plot(as.mlt(mw), type = "survivor", newdata = nd1, col = col)
 
-## ----COX-model-fit, echo = FALSE, cache = TRUE--------------------------
+## ----COX-model-fit, echo = FALSE, cache = TRUE---------------------------
 mc <-
-Coxph(iDFS ~ randarm, data = CAOsurv, log_first = TRUE)
+Coxph(iDFS ~ randarm, data = CAOsurv)
 
-## ----COX-summary, cache = TRUE, results = "hide", fig.show = "hide"-----
+## ----COX-summary, cache = TRUE, results = "hide", fig.show = "hide"------
 summary(mc)
 score_test(mc)
 perm_test(mc)
 # plot(as.mlt(mc), type = "survivor", newdata = nd1, col = col)
 
-## ----COX-lHaz, echo = FALSE---------------------------------------------
-## confband
-object <- as.mlt(mc)
-newdata <- nd1[1,, drop = FALSE]
-K <- 20
-cheat <- 200
-y <- variable.names(object, "response")
-q <- mkgrid(object, n = K)[[y]]
-q[1] <- q[1] + 1 ## quick fix for log_first
-nd <- newdata[rep(1, length(q)), , drop = FALSE]
-nd[[y]] <- q
-X <- model.matrix(object$model$model, data = nd)
-cb <- confint(multcomp::glht(multcomp::parm(coef(object), 
-  vcov(object)), linfct = X))$confint
-q <- mkgrid(object, n = cheat)[[y]]
-q[1] <- q[1] + 1 ## quick fix for log_first 
-nd <- newdata[rep(1, length(q)), , drop = FALSE]
-nd[[y]] <- q
-X <- model.matrix(object$model$model, data = nd)
-cb <- confint(multcomp::glht(multcomp::parm(coef(object), 
-  vcov(object)), linfct = X), calpha = attr(cb, 
-        "calpha"))$confint
-cb <- cbind(q, cb)
+## ----COX-lHaz-try--------------------------------------------------------
+cb <- confband(as.mlt(mc), newdata =  nd1[1,, drop = FALSE], K = 20, cheat = 100)
 
-## ----COX-lHaz-plot------------------------------------------------------
+## ----COX-lHaz-plot-------------------------------------------------------
 eval(par_main)
+cb <- cb[cb[,"q"] > 0,] ### remove time = 0
 plot(cb[, "q"], cb[, "Estimate"], log = "x", type = "n",
   xlab = lxlab, ylab = ylablHaz, xlim = xlimlHaz <- range(cb[, "q"]),
   ylim = range(cb[, -1]))
@@ -388,34 +368,38 @@ polygon(c(cb[, "q"], rev(cb[, "q"])), c(cb[, "lwr"], rev(cb[, "upr"])),
   border = NA, col = rgb(.1, .1, .1, .1))
 lines(cb[, "q"], cb[, "Estimate"], lwd = lwd)
 
-## ----STRAT-model-fit, cache = TRUE--------------------------------------
+## ----fastopt-------------------------------------------------------------
+fastopt <- mltoptim(abstol = 1e-3, reltol = 1e-3)
+fastoptH <- mltoptim(abstol = 1e-3, reltol = 1e-3, hessian = TRUE)
+
+## ----STRAT-model-fit, cache = TRUE---------------------------------------
 mcst <- 
-Coxph(iDFS | strat ~ randarm, data = CAOsurv, log_first = TRUE)
+Coxph(iDFS | strat ~ randarm, data = CAOsurv, optim = fastopt)
 
 ## ----STRAT-summary, cache = TRUE, results = "hide", fig.show = "hide"----
 summary(mcst)
 score_test(mcst)
 perm_test(mcst)
 
-## ----STRAT-lHaz-plot----------------------------------------------------
-plot(as.mlt(mcst), newdata = nd2, q = q, type = "trafo", log = "x",
+## ----STRAT-lHaz-plot-----------------------------------------------------
+plot(as.mlt(mcst), newdata = nd2, q = q[q > 0], type = "logcumhazard", log = "x",
   lty = lty <- 1:4, xlab = lxlab, ylab = ylablHaz, xlim = xlimlHaz,
   col = 1, lwd = lwd)
 
 legend("bottomright", legend = lslevs, title = "Stratum", 
   lty = lty, lwd = lwd, col = 1, bty = "n")
 
-## ----SCOX-model-fit, cache = TRUE---------------------------------------
+## ----SCOX-model-fit, cache = TRUE----------------------------------------
 mcs <- 
-Coxph(iDFS ~ randarm | randarm, data = CAOsurv, log_first = TRUE)
+Coxph(iDFS ~ randarm | randarm, data = CAOsurv)
 
-## ----SCOX-summary, cache = TRUE, results = "hide", fig.show = "hide"----
+## ----SCOX-summary, cache = TRUE, results = "hide", fig.show = "hide"-----
 summary(mcs)
 confint(mcs)
 perm_test_biv.stram(mcs)
 # plot(as.mlt(mcs), type = "survivor", newdata = nd1, col = col)
 
-## ----SCOX-survplot, fig.show = "hide"-----------------------------------
+## ----SCOX-survplot, fig.show = "hide"------------------------------------
 eval(par_surv)
 plot(surv_iDFS, ylim = ylimS, xlim = xlim,
   col = lcol, lwd = lwd, xlab = xlab, ylab = ylabS)
@@ -423,7 +407,7 @@ legend("bottomright", legend = levs, col = col, bty = "n", lty = 1, lwd = 1, cex
 plot.risktab(tvar = "iDFStime")
 plot(as.mlt(mcs), type = "survivor", newdata = nd1, col = col, add = TRUE)
 
-## ----SCOX-HR-plot, echo = FALSE-----------------------------------------
+## ----SCOX-HR-plot, echo = FALSE------------------------------------------
 qHR <- seq(50, max(q), by = 1)
 cumhaz <- predict(mcs, type = "cumhazard", newdata = nd1, q = qHR)
 cumhr <- unname(cumhaz[, 2] / cumhaz[, 1])
@@ -433,14 +417,14 @@ plot(qHR, cumhr, type = "l", ylab = ylabcumHR, xlab = xlab,
 abline(h = exp(coef(mc)), lty = 2, lwd = 1) ## constant HR
 abline(h = 1, lty = 3) ## HR = 1
 
-## ----TCOX-model-fit, cache = TRUE---------------------------------------
+## ----TCOX-model-fit, cache = TRUE----------------------------------------
 mcv <- 
-Coxph(iDFS | randarm ~ 1, data = CAOsurv, log_first = TRUE)
+Coxph(iDFS | randarm ~ 1, data = CAOsurv)
 
-## ----TCOX-summary, cache = TRUE, results = "hide", fig.show = 'hide'----
+## ----TCOX-summary, cache = TRUE, results = "hide", fig.show = 'hide'-----
 logLik(mcv)
 
-## ----TCOX-HR, cache = TRUE----------------------------------------------
+## ----TCOX-HR, cache = TRUE-----------------------------------------------
 mcv <- as.mlt(mcv)
 
 ## grid (was n = 500, qmvnorm failed)
@@ -459,7 +443,7 @@ coxy <- s$iDFS
 ## confint for constant HR
 ci2 <- exp(confint(mc))
 
-## ----TCOX-HR-plot-------------------------------------------------------
+## ----TCOX-HR-plot--------------------------------------------------------
 plot(coxy, ci[, "Estimate"], ylim = ylimHR, type = "n",
   xlim = xlimHR, xlab = xlab, ylab = ylabcumHR)
 polygon(c(coxy, rev(coxy)), c(ci[,"lwr"], rev(ci[, "upr"])),
@@ -474,7 +458,7 @@ abline(h = exp(coef(mc)), lty = 2, lwd = 1)
 ## HR = 1
 abline(h = 1, lty = 3)
 
-## ----DEPCENS-preproc, echo = FALSE--------------------------------------
+## ----DEPCENS-preproc, echo = FALSE---------------------------------------
 ## DepC: loss of follow-up (everyone else is admin censored) Mail TH 23-06-12
 patnr_lofu <-c(1012, 2003, 3002, 3003, 6018, 7001, 7003, 7005, 7008, 7012, 10003,
               10012, 11018, 12003, 12014, 13028, 14002, 15001, 16001, 16004, 16005,
@@ -492,65 +476,67 @@ CAOsurv$DepCevent <- factor(as.numeric(CAOsurv$DepCevent), levels = 0:2,
   labels = c("AdminC", "EoI", "DepC"))
 CAOsurv$DepCevent[ilofu] <- "DepC"
 
-## ----DEPCENS-table, results = 'hide'------------------------------------
+## ----DEPCENS-table, results = 'hide'-------------------------------------
 CAOsurv$nDepCevent <- factor(as.character(CAOsurv$DepCevent),
   levels = c("AdminC", "EoI", "DepC"), 
   labels = c("Administrative censoring", "Event of interest", "Loss of follow-up"))
 tab <- xtabs(~ nDepCevent + randarm, data = CAOsurv)
 tab
 
-## ----DEPCENS-model-fit, cache = TRUE------------------------------------
+## ----DEPCENS-model-fit, cache = TRUE-------------------------------------
 md <- 
-Coxph(Surv(OStime, event = DepCevent) ~ randarm, data = CAOsurv,
-  log_first = TRUE)
+Coxph(Surv(OStime, event = DepCevent) ~ randarm, data = CAOsurv, 
+      optim = fastoptH)
 
 ## ----DEPCENS-summary, cache = TRUE, results = "hide", fig.show = 'hide'----
 summary(md)
 confint(md)
 
-## ----COXME-install, echo = TRUE, eval = FALSE---------------------------
+## ----COXME-install, echo = TRUE, eval = FALSE----------------------------
 # install.packages("tramME")
 # library("tramME")
 
-## ----COXME-load---------------------------------------------------------
+## ----COXME-load----------------------------------------------------------
 library("tramME")
 
-## ----COXME-model-fit, cache = TRUE--------------------------------------
+## ----COXME-model-fit, cache = TRUE---------------------------------------
 mcME <- 
-CoxphME(iDFS ~ randarm + (1 | Block), data = CAOsurv,
-  log_first = TRUE)
+CoxphME(iDFS ~ randarm + (1 | Block), data = CAOsurv)
 
 ## ----COXME-summary, cache = TRUE, results = "hide", fig.show = 'hide'----
 summary(mcME)
 confint(mcME)
 
-## ----COXME-margsurv, eval = FALSE---------------------------------------
+## ----COXME-margsurv, eval = FALSE----------------------------------------
 # ## computationally intensive
+# if (!file.exists("ME-margdist.rda")) {
 # mod <- mcME
 # 
 # ## A function to evaluate the joint cdf of the response and the random effects:
 # ## Takes a vector of random effect and covariates values, evaluates the conditional
 # ## distribution at these values and multiplies it with the pdf of the random effects
 # jointCDF <- function(re, nd, mod) {
-#   nd <- nd[rep(1, length(re)), ]
-#   nd$Block <- seq(nrow(nd)) ## to take vector-valued REs
-#   pr <- predict(mod, newdata = nd, ranef = re, type = "distribution") *
-#   dnorm(re, 0, sd = sqrt(varcov(mod)[[1]][1, 1]))
-#   c(pr)
+# nd <- nd[rep(1, length(re)), ]
+# nd$Block <- seq(nrow(nd)) ## to take vector-valued REs
+# pr <- predict(mod, newdata = nd, ranef = re, type = "distribution") *
+# dnorm(re, 0, sd = sqrt(varcov(mod)[[1]][1, 1]))
+# c(pr)
 # }
 # ## Marginalize the joint cdf by integrating out the random effects
 # ## using adaptive quadrature
 # marginalCDF <- function(nd, mod) {
-#   nd$cdf <- integrate(jointCDF, lower = -Inf, upper = Inf, nd = nd, mod = mod)$value
-#   nd
+# nd$cdf <- integrate(jointCDF, lower = -Inf, upper = Inf, nd = nd, mod = mod)$value
+# nd
 # }
 # ## Set up the grid on which we evaluate the marginal distribution
 # nd <- expand.grid(iDFS = 1:max(CAOsurv$DFStime), randarm = unique(CAOsurv$randarm))
 # ## Calls marginalCDF on each row of nd
 # ## (done in parallel to speed up computations)
 # mp <- parallel::mclapply(split(nd, seq(nrow(nd))),
-#   marginalCDF, mod = mod, mc.cores = 1)
+#   marginalCDF, mod = mod, mc.cores = 4)
 # mp <- do.call("rbind", mp)
+# save(mp, file = "ME-margdist.rda")
+# } else load("ME-margdist.rda")
 # mp$surv <- with(mp, 1 - cdf)
 # 
 # <<plot-surv-iDFS, eval = FALSE>>
@@ -558,7 +544,7 @@ confint(mcME)
 # with(mp[mp$randarm == levs[2], ], lines(iDFS, surv, col = col[2], lwd = lwd))
 # legend("bottomright", legend = levs, col = col, bty = "n", lty = 1, lwd = 1, cex = .8)
 
-## ----MCOX-preproc, echo = FALSE-----------------------------------------
+## ----MCOX-preproc, echo = FALSE------------------------------------------
 ### convert "exact" event dates to interval-censoring (+/- two days)
 tmp <- CAOsurv$iDFS
 exact <- tmp[, 3] == 1
@@ -567,12 +553,12 @@ tmp[exact, 1] <- pmax(tmp[exact, 1] - 2, 0)
 tmp[exact, 3] <- 3
 CAOsurv$iDFS2 <- tmp
 
-## ----MCOX-model-fit, cache = TRUE---------------------------------------
+## ----MCOX-model-fit, cache = TRUE----------------------------------------
 mmc <- 
-mtram(Coxph(iDFS2 ~ randarm, data = CAOsurv, log_first = TRUE),
-  formula = ~ (1 | Block), data = CAOsurv)
+mtram(Coxph(iDFS2 ~ randarm, data = CAOsurv),
+  formula = ~ (1 | Block), data = CAOsurv, optim = fastoptH)
 
-## ----MCOX-FUN-----------------------------------------------------------
+## ----MCOX-FUN------------------------------------------------------------
 ## marginal HR from "mtram"
 ## <FIXME> reset seed on.exit </FIXME>
 mHR.mtram <- function(object, with_confint = FALSE, seed = 1) {
@@ -595,15 +581,15 @@ mHR.mtram <- function(object, with_confint = FALSE, seed = 1) {
   return(ret)
 }
 
-## ----MCOX-summary, cache = TRUE, results = "hide", fig.show = 'hide'----
+## ----MCOX-summary, cache = TRUE, results = "hide", fig.show = 'hide'-----
 coef(mmc)
 sqrt(diag(vcov(mmc)))
 (ci_MCOX <- mHR.mtram(mmc, with_confint = TRUE))
 
-## ----HTECOX-model-fit, cache = TRUE-------------------------------------
+## ----HTECOX-model-fit, cache = TRUE--------------------------------------
 ma <- 
 CoxphME(iDFS ~ randarm + s(age, by = as.ordered(randarm),
-    fx = TRUE, k = 6), data = CAOsurv, log_first = TRUE)
+    fx = TRUE, k = 6), data = CAOsurv)
 nd <- model.frame(ma)[rep(2, 100), ]
 nd$age <- seq(min(CAOsurv$age), max(CAOsurv$age), length.out = 100)
 xx <- model.matrix(ma, data = nd, type = "X", keep_sign = FALSE)$X
@@ -618,7 +604,7 @@ cb <- exp(confint(multcomp::glht(multcomp::parm(bb, vc), linfct = xx),
 ## ----HTECOX-summary, cache = TRUE, results = "hide", fig.show = 'hide'----
 summary(ma)
 
-## ----HTECOX-HR-plot-----------------------------------------------------
+## ----HTECOX-HR-plot------------------------------------------------------
 ## Plot HR
 plot(nd$age, cb[, "Estimate"], type = "n", ylab = "Hazard ratio", xlab = "Age (in years)",
      ylim = ylimHR)
@@ -628,31 +614,32 @@ lines(nd$age, cb[, "Estimate"], lwd = lwd)
 abline(h = 1, lty = 3)
 rug(CAOsurv$age, lwd = 2, col = rgb(.1, .1, .1, .1))
 
-## ----TRT-load-install, echo = TRUE, eval = FALSE------------------------
+## ----TRT-load-install, echo = TRUE, eval = FALSE-------------------------
 # install.packages("trtf")
 # library("trtf")
 
-## ----TRT-load-----------------------------------------------------------
+## ----TRT-load------------------------------------------------------------
 library("trtf")
 set.seed(4)
 
-## ----TRTF-model-fit, cache = TRUE, warning=TRUE-------------------------
+## ----TRTF-model-fit, cache = TRUE, warning = FALSE-----------------------
 tr <-
-trafotree(Coxph(iDFS ~ randarm, data = CAOsurv, log_first = TRUE),
+trafotree(Coxph(iDFS ~ randarm, data = CAOsurv),
   formula = iDFS ~ randarm | age, data = CAOsurv,
-  control = ctree_control(teststat = "maximum", minbucket = 40))
+  control = ctree_control(teststat = "maximum", alpha = .1,
+    minbucket = 40))
 
-## ----TRT-results, results = "hide", fig.show = 'hide'-------------------
+## ----TRT-results, results = "hide", fig.show = 'hide'--------------------
 logLik(tr)
 
-## ----TRTF-surv-plot, fig.width = 10, fig.height = 6---------------------
+## ----TRTF-surv-plot, fig.width = 10, fig.height = 6----------------------
 library("ATR")
 plot(rotate(tr), tp_args = list(newdata = nd1, type = "survivor", col = col, lwd = lwd),
   terminal_panel = trtf:::node_mlt)
 
-## ----FRAILTY-model-fit, cache = TRUE------------------------------------
+## ----FRAILTY-model-fit, cache = TRUE-------------------------------------
 mf <- 
-Coxph(iDFS ~ randarm, data = CAOsurv, log_first = TRUE, frailty = "Gamma")
+Coxph(iDFS ~ randarm, data = CAOsurv, frailty = "Gamma")
 
 ## ----FRAILTY-summary, cache = TRUE, results = "hide", fig.show = 'hide'----
 logLik(mf)
@@ -660,38 +647,38 @@ coef(mf)[trt]
 coef(mf, addparm = TRUE)
 confint(mf, parm = c(trt, "logrho"))
 
-## ----LOGIT-model-fit----------------------------------------------------
+## ----LOGIT-model-fit-----------------------------------------------------
 ml <- 
-Colr(iDFS ~ randarm, data = CAOsurv, log_first = TRUE)
+Colr(iDFS ~ randarm, data = CAOsurv)
 
-## ----SS, echo = TRUE----------------------------------------------------
+## ----SS, echo = TRUE-----------------------------------------------------
 m <- as.mlt(Survreg(OS ~ randarm + age, data = CAOsurv, 
   dist = "weibull", support = c(.1, 80 * 365)))
 
-## ----SS-nd--------------------------------------------------------------
+## ----SS-nd---------------------------------------------------------------
 N <- 500
 nd <- with(CAOsurv, data.frame(randarm = gl(2, N, labels = levels(randarm)),
   age = rnorm(N, mean = mean(age), sd = sd(age))))
 
-## ----SS-setup, echo = FALSE---------------------------------------------
+## ----SS-setup, echo = FALSE----------------------------------------------
 `coef<-` <- mlt::`coef<-` ## masked by tramME?
 
-## ----SS-lOR, echo = TRUE------------------------------------------------
+## ----SS-lOR, echo = TRUE-------------------------------------------------
 cf <- coef(m)
 cf["randarm5-FU + Oxaliplatin"] <- .25
 coef(m) <- cf
 nd$T <- as.Surv(simulate(m, newdata = nd, K = 1000))
 
-## ----SS-simC, echo = TRUE-----------------------------------------------
+## ----SS-simC, echo = TRUE------------------------------------------------
 cf["(Intercept)"] <- cf["(Intercept)"] + qlogis(.8)
 coef(m) <- cf
 nd$C <- as.Surv(simulate(m, newdata = nd, K = 1000))
 
-## ----SS-OS, echo = TRUE, results = "asis"-------------------------------
+## ----SS-OS, echo = TRUE, results = "asis"--------------------------------
 nd$nOS <- with(nd, Surv(time = pmin(T[, "time"], C[, "time"]),
   event = T[,"time"] < C[,"time"]))
 
-## ----SS-refit, eval = FALSE, results = "hide", fig.show = "hide"--------
+## ----SS-refit, eval = FALSE, results = "hide", fig.show = "hide"---------
 # table(nd$nOS[,"status"])
 # levels(nd$randarm)[2] <- "innovative"
 # plot(survfit(nOS ~ randarm, data = nd), col = col, xlab = "Time (in days)",
